==> huaweicloudsdkcpts-3.0.59-py2.py3-none-any.whl: huaweicloudsdkcpts/v1/model/update_task_status_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateTaskStatusResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'code': 'str',
        'message': 'str',
        'extend': 'str',
        'result': 'UpdateTaskStatusResqResult'
    }

    attribute_map = {
        'code': 'code',
        'message': 'message',
        'extend': 'extend',
        'result': 'result'
    }

    def __init__(self, code=None, message=None, extend=None, result=None):
        """UpdateTaskStatusResponse - a model defined in huaweicloud sdk"""
        
        super(UpdateTaskStatusResponse, self).__init__()

        self._code = None
        self._message = None
        self._extend = None
        self._result = None
        self.discriminator = None

        if code is not None:
            self.code = code
        if message is not None:
            self.message = message
        if extend is not None:
            self.extend = extend
        if result is not None:
            self.result = result

    @property
    def code(self):
        """Gets the code of this UpdateTaskStatusResponse.

        code

        :return: The code of this UpdateTaskStatusResponse.
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this UpdateTaskStatusResponse.

        code

        :param code: The code of this UpdateTaskStatusResponse.
        :type: str
        """
        self._code = code

    @property
    def message(self):
        """Gets the message of this UpdateTaskStatusResponse.

        message

        :return: The message of this UpdateTaskStatusResponse.
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this UpdateTaskStatusResponse.

        message

        :param message: The message of this UpdateTaskStatusResponse.
        :type: str
        """
        self._message = message

    @property
    def extend(self):
        """Gets the extend of this UpdateTaskStatusResponse.

        extend

        :return: The extend of this UpdateTaskStatusResponse.
        :rtype: str
        """
        return self._extend

    @extend.setter
    def extend(self, extend):
        """Sets the extend of this UpdateTaskStatusResponse.

        extend

        :param extend: The extend of this UpdateTaskStatusResponse.
        :type: str
        """
        self._extend = extend

    @property
    def result(self):
        """Gets the result of this UpdateTaskStatusResponse.


        :return: The result of this UpdateTaskStatusResponse.
        :rtype: UpdateTaskStatusResqResult
        """
        return self._result

    @result.setter
    def result(self, result):
        """Sets the result of this UpdateTaskStatusResponse.


        :param result: The result of this UpdateTaskStatusResponse.
        :type: UpdateTaskStatusResqResult
        """
        self._result = result

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateTaskStatusResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcpts-3.0.66-py2.py3-none-any.whl: huaweicloudsdkcpts/v1/model/update_task_status_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateTaskStatusResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'code': 'str',
        'message': 'str',
        'extend': 'str',
        'result': 'UpdateTaskStatusResult'
    }

    attribute_map = {
        'code': 'code',
        'message': 'message',
        'extend': 'extend',
        'result': 'result'
    }

    def __init__(self, code=None, message=None, extend=None, result=None):
        """UpdateTaskStatusResponse - a model defined in huaweicloud sdk"""
        
        super(UpdateTaskStatusResponse, self).__init__()

        self._code = None
        self._message = None
        self._extend = None
        self._result = None
        self.discriminator = None

        if code is not None:
            self.code = code
        if message is not None:
            self.message = message
        if extend is not None:
            self.extend = extend
        if result is not None:
            self.result = result

    @property
    def code(self):
        """Gets the code of this UpdateTaskStatusResponse.

        code

        :return: The code of this UpdateTaskStatusResponse.
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this UpdateTaskStatusResponse.

        code

        :param code: The code of this UpdateTaskStatusResponse.
        :type: str
        """
        self._code = code

    @property
    def message(self):
        """Gets the message of this UpdateTaskStatusResponse.

        message

        :return: The message of this UpdateTaskStatusResponse.
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this UpdateTaskStatusResponse.

        message

        :param message: The message of this UpdateTaskStatusResponse.
        :type: str
        """
        self._message = message

    @property
    def extend(self):
        """Gets the extend of this UpdateTaskStatusResponse.

        extend

        :return: The extend of this UpdateTaskStatusResponse.
        :rtype: str
        """
        return self._extend

    @extend.setter
    def extend(self, extend):
        """Sets the extend of this UpdateTaskStatusResponse.

        extend

        :param extend: The extend of this UpdateTaskStatusResponse.
        :type: str
        """
        self._extend = extend

    @property
    def result(self):
        """Gets the result of this UpdateTaskStatusResponse.


        :return: The result of this UpdateTaskStatusResponse.
        :rtype: UpdateTaskStatusResult
        """
        return self._result

    @result.setter
    def result(self, result):
        """Sets the result of this UpdateTaskStatusResponse.


        :param result: The result of this UpdateTaskStatusResponse.
        :type: UpdateTaskStatusResult
        """
        self._result = result

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateTaskStatusResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
